sqlglot.token_type API documentation

Edit on GitHub

# sqlglot.token_type

View Source

      1from enum import auto
      2
      3from sqlglot.helper import AutoName
      4
      5
      6class TokenType(AutoName):
      7    L_PAREN = auto()
      8    R_PAREN = auto()
      9    L_BRACKET = auto()
     10    R_BRACKET = auto()
     11    L_BRACE = auto()
     12    R_BRACE = auto()
     13    COMMA = auto()
     14    DOT = auto()
     15    DASH = auto()
     16    PLUS = auto()
     17    COLON = auto()
     18    DCOLON = auto()
     19    DQMARK = auto()
     20    SEMICOLON = auto()
     21    STAR = auto()
     22    BACKSLASH = auto()
     23    SLASH = auto()
     24    LT = auto()
     25    LTE = auto()
     26    GT = auto()
     27    GTE = auto()
     28    NOT = auto()
     29    EQ = auto()
     30    NEQ = auto()
     31    NULLSAFE_EQ = auto()
     32    COLON_EQ = auto()
     33    AND = auto()
     34    OR = auto()
     35    AMP = auto()
     36    DPIPE = auto()
     37    PIPE = auto()
     38    CARET = auto()
     39    TILDA = auto()
     40    ARROW = auto()
     41    DARROW = auto()
     42    FARROW = auto()
     43    HASH = auto()
     44    HASH_ARROW = auto()
     45    DHASH_ARROW = auto()
     46    LR_ARROW = auto()
     47    DAT = auto()
     48    LT_AT = auto()
     49    AT_GT = auto()
     50    DOLLAR = auto()
     51    PARAMETER = auto()
     52    SESSION_PARAMETER = auto()
     53    DAMP = auto()
     54    XOR = auto()
     55    DSTAR = auto()
     56
     57    BLOCK_START = auto()
     58    BLOCK_END = auto()
     59
     60    SPACE = auto()
     61    BREAK = auto()
     62
     63    STRING = auto()
     64    NUMBER = auto()
     65    IDENTIFIER = auto()
     66    DATABASE = auto()
     67    COLUMN = auto()
     68    COLUMN_DEF = auto()
     69    SCHEMA = auto()
     70    TABLE = auto()
     71    VAR = auto()
     72    BIT_STRING = auto()
     73    HEX_STRING = auto()
     74    BYTE_STRING = auto()
     75    NATIONAL_STRING = auto()
     76    RAW_STRING = auto()
     77    HEREDOC_STRING = auto()
     78
     79    # types
     80    BIT = auto()
     81    BOOLEAN = auto()
     82    TINYINT = auto()
     83    UTINYINT = auto()
     84    SMALLINT = auto()
     85    USMALLINT = auto()
     86    MEDIUMINT = auto()
     87    UMEDIUMINT = auto()
     88    INT = auto()
     89    UINT = auto()
     90    BIGINT = auto()
     91    UBIGINT = auto()
     92    INT128 = auto()
     93    UINT128 = auto()
     94    INT256 = auto()
     95    UINT256 = auto()
     96    FLOAT = auto()
     97    DOUBLE = auto()
     98    DECIMAL = auto()
     99    UDECIMAL = auto()
    100    BIGDECIMAL = auto()
    101    CHAR = auto()
    102    NCHAR = auto()
    103    VARCHAR = auto()
    104    NVARCHAR = auto()
    105    TEXT = auto()
    106    MEDIUMTEXT = auto()
    107    LONGTEXT = auto()
    108    MEDIUMBLOB = auto()
    109    LONGBLOB = auto()
    110    TINYBLOB = auto()
    111    TINYTEXT = auto()
    112    BINARY = auto()
    113    VARBINARY = auto()
    114    JSON = auto()
    115    JSONB = auto()
    116    TIME = auto()
    117    TIMETZ = auto()
    118    TIMESTAMP = auto()
    119    TIMESTAMPTZ = auto()
    120    TIMESTAMPLTZ = auto()
    121    TIMESTAMP_S = auto()
    122    TIMESTAMP_MS = auto()
    123    TIMESTAMP_NS = auto()
    124    DATETIME = auto()
    125    DATETIME64 = auto()
    126    DATE = auto()
    127    INT4RANGE = auto()
    128    INT4MULTIRANGE = auto()
    129    INT8RANGE = auto()
    130    INT8MULTIRANGE = auto()
    131    NUMRANGE = auto()
    132    NUMMULTIRANGE = auto()
    133    TSRANGE = auto()
    134    TSMULTIRANGE = auto()
    135    TSTZRANGE = auto()
    136    TSTZMULTIRANGE = auto()
    137    DATERANGE = auto()
    138    DATEMULTIRANGE = auto()
    139    UUID = auto()
    140    GEOGRAPHY = auto()
    141    NULLABLE = auto()
    142    GEOMETRY = auto()
    143    HLLSKETCH = auto()
    144    HSTORE = auto()
    145    SUPER = auto()
    146    SERIAL = auto()
    147    SMALLSERIAL = auto()
    148    BIGSERIAL = auto()
    149    XML = auto()
    150    YEAR = auto()
    151    UNIQUEIDENTIFIER = auto()
    152    USERDEFINED = auto()
    153    MONEY = auto()
    154    SMALLMONEY = auto()
    155    ROWVERSION = auto()
    156    IMAGE = auto()
    157    VARIANT = auto()
    158    OBJECT = auto()
    159    INET = auto()
    160    IPADDRESS = auto()
    161    IPPREFIX = auto()
    162    ENUM = auto()
    163    ENUM8 = auto()
    164    ENUM16 = auto()
    165    FIXEDSTRING = auto()
    166    LOWCARDINALITY = auto()
    167    NESTED = auto()
    168    UNKNOWN = auto()
    169
    170    # keywords
    171    ALIAS = auto()
    172    ALTER = auto()
    173    ALWAYS = auto()
    174    ALL = auto()
    175    ANTI = auto()
    176    ANY = auto()
    177    APPLY = auto()
    178    ARRAY = auto()
    179    ASC = auto()
    180    ASOF = auto()
    181    AUTO_INCREMENT = auto()
    182    BEGIN = auto()
    183    BETWEEN = auto()
    184    CACHE = auto()
    185    CASE = auto()
    186    CHARACTER_SET = auto()
    187    CLUSTER_BY = auto()
    188    COLLATE = auto()
    189    COMMAND = auto()
    190    COMMENT = auto()
    191    COMMIT = auto()
    192    CONNECT_BY = auto()
    193    CONSTRAINT = auto()
    194    CREATE = auto()
    195    CROSS = auto()
    196    CUBE = auto()
    197    CURRENT_DATE = auto()
    198    CURRENT_DATETIME = auto()
    199    CURRENT_TIME = auto()
    200    CURRENT_TIMESTAMP = auto()
    201    CURRENT_USER = auto()
    202    DEFAULT = auto()
    203    DELETE = auto()
    204    DESC = auto()
    205    DESCRIBE = auto()
    206    DICTIONARY = auto()
    207    DISTINCT = auto()
    208    DISTRIBUTE_BY = auto()
    209    DIV = auto()
    210    DROP = auto()
    211    ELSE = auto()
    212    END = auto()
    213    ESCAPE = auto()
    214    EXCEPT = auto()
    215    EXECUTE = auto()
    216    EXISTS = auto()
    217    FALSE = auto()
    218    FETCH = auto()
    219    FILTER = auto()
    220    FINAL = auto()
    221    FIRST = auto()
    222    FOR = auto()
    223    FORCE = auto()
    224    FOREIGN_KEY = auto()
    225    FORMAT = auto()
    226    FROM = auto()
    227    FULL = auto()
    228    FUNCTION = auto()
    229    GLOB = auto()
    230    GLOBAL = auto()
    231    GROUP_BY = auto()
    232    GROUPING_SETS = auto()
    233    HAVING = auto()
    234    HINT = auto()
    235    IGNORE = auto()
    236    ILIKE = auto()
    237    ILIKE_ANY = auto()
    238    IN = auto()
    239    INDEX = auto()
    240    INNER = auto()
    241    INSERT = auto()
    242    INTERSECT = auto()
    243    INTERVAL = auto()
    244    INTO = auto()
    245    INTRODUCER = auto()
    246    IRLIKE = auto()
    247    IS = auto()
    248    ISNULL = auto()
    249    JOIN = auto()
    250    JOIN_MARKER = auto()
    251    KEEP = auto()
    252    KILL = auto()
    253    LANGUAGE = auto()
    254    LATERAL = auto()
    255    LEFT = auto()
    256    LIKE = auto()
    257    LIKE_ANY = auto()
    258    LIMIT = auto()
    259    LOAD = auto()
    260    LOCK = auto()
    261    MAP = auto()
    262    MATCH_RECOGNIZE = auto()
    263    MEMBER_OF = auto()
    264    MERGE = auto()
    265    MOD = auto()
    266    MODEL = auto()
    267    NATURAL = auto()
    268    NEXT = auto()
    269    NOTNULL = auto()
    270    NULL = auto()
    271    OBJECT_IDENTIFIER = auto()
    272    OFFSET = auto()
    273    ON = auto()
    274    OPERATOR = auto()
    275    ORDER_BY = auto()
    276    ORDERED = auto()
    277    ORDINALITY = auto()
    278    OUTER = auto()
    279    OVER = auto()
    280    OVERLAPS = auto()
    281    OVERWRITE = auto()
    282    PARTITION = auto()
    283    PARTITION_BY = auto()
    284    PERCENT = auto()
    285    PIVOT = auto()
    286    PLACEHOLDER = auto()
    287    PRAGMA = auto()
    288    PRIMARY_KEY = auto()
    289    PROCEDURE = auto()
    290    PROPERTIES = auto()
    291    PSEUDO_TYPE = auto()
    292    QUALIFY = auto()
    293    QUOTE = auto()
    294    RANGE = auto()
    295    RECURSIVE = auto()
    296    REFRESH = auto()
    297    REPLACE = auto()
    298    RETURNING = auto()
    299    REFERENCES = auto()
    300    RIGHT = auto()
    301    RLIKE = auto()
    302    ROLLBACK = auto()
    303    ROLLUP = auto()
    304    ROW = auto()
    305    ROWS = auto()
    306    SELECT = auto()
    307    SEMI = auto()
    308    SEPARATOR = auto()
    309    SERDE_PROPERTIES = auto()
    310    SET = auto()
    311    SETTINGS = auto()
    312    SHOW = auto()
    313    SIMILAR_TO = auto()
    314    SOME = auto()
    315    SORT_BY = auto()
    316    START_WITH = auto()
    317    STRUCT = auto()
    318    TABLE_SAMPLE = auto()
    319    TEMPORARY = auto()
    320    TOP = auto()
    321    THEN = auto()
    322    TRUE = auto()
    323    UNCACHE = auto()
    324    UNION = auto()
    325    UNNEST = auto()
    326    UNPIVOT = auto()
    327    UPDATE = auto()
    328    USE = auto()
    329    USING = auto()
    330    VALUES = auto()
    331    VIEW = auto()
    332    VOLATILE = auto()
    333    WHEN = auto()
    334    WHERE = auto()
    335    WINDOW = auto()
    336    WITH = auto()
    337    UNIQUE = auto()
    338    VERSION_SNAPSHOT = auto()
    339    TIMESTAMP_SNAPSHOT = auto()

class TokenType(sqlglot.helper.AutoName): View Source

      7class TokenType(AutoName):
      8    L_PAREN = auto()
      9    R_PAREN = auto()
     10    L_BRACKET = auto()
     11    R_BRACKET = auto()
     12    L_BRACE = auto()
     13    R_BRACE = auto()
     14    COMMA = auto()
     15    DOT = auto()
     16    DASH = auto()
     17    PLUS = auto()
     18    COLON = auto()
     19    DCOLON = auto()
     20    DQMARK = auto()
     21    SEMICOLON = auto()
     22    STAR = auto()
     23    BACKSLASH = auto()
     24    SLASH = auto()
     25    LT = auto()
     26    LTE = auto()
     27    GT = auto()
     28    GTE = auto()
     29    NOT = auto()
     30    EQ = auto()
     31    NEQ = auto()
     32    NULLSAFE_EQ = auto()
     33    COLON_EQ = auto()
     34    AND = auto()
     35    OR = auto()
     36    AMP = auto()
     37    DPIPE = auto()
     38    PIPE = auto()
     39    CARET = auto()
     40    TILDA = auto()
     41    ARROW = auto()
     42    DARROW = auto()
     43    FARROW = auto()
     44    HASH = auto()
     45    HASH_ARROW = auto()
     46    DHASH_ARROW = auto()
     47    LR_ARROW = auto()
     48    DAT = auto()
     49    LT_AT = auto()
     50    AT_GT = auto()
     51    DOLLAR = auto()
     52    PARAMETER = auto()
     53    SESSION_PARAMETER = auto()
     54    DAMP = auto()
     55    XOR = auto()
     56    DSTAR = auto()
     57
     58    BLOCK_START = auto()
     59    BLOCK_END = auto()
     60
     61    SPACE = auto()
     62    BREAK = auto()
     63
     64    STRING = auto()
     65    NUMBER = auto()
     66    IDENTIFIER = auto()
     67    DATABASE = auto()
     68    COLUMN = auto()
     69    COLUMN_DEF = auto()
     70    SCHEMA = auto()
     71    TABLE = auto()
     72    VAR = auto()
     73    BIT_STRING = auto()
     74    HEX_STRING = auto()
     75    BYTE_STRING = auto()
     76    NATIONAL_STRING = auto()
     77    RAW_STRING = auto()
     78    HEREDOC_STRING = auto()
     79
     80    # types
     81    BIT = auto()
     82    BOOLEAN = auto()
     83    TINYINT = auto()
     84    UTINYINT = auto()
     85    SMALLINT = auto()
     86    USMALLINT = auto()
     87    MEDIUMINT = auto()
     88    UMEDIUMINT = auto()
     89    INT = auto()
     90    UINT = auto()
     91    BIGINT = auto()
     92    UBIGINT = auto()
     93    INT128 = auto()
     94    UINT128 = auto()
     95    INT256 = auto()
     96    UINT256 = auto()
     97    FLOAT = auto()
     98    DOUBLE = auto()
     99    DECIMAL = auto()
    100    UDECIMAL = auto()
    101    BIGDECIMAL = auto()
    102    CHAR = auto()
    103    NCHAR = auto()
    104    VARCHAR = auto()
    105    NVARCHAR = auto()
    106    TEXT = auto()
    107    MEDIUMTEXT = auto()
    108    LONGTEXT = auto()
    109    MEDIUMBLOB = auto()
    110    LONGBLOB = auto()
    111    TINYBLOB = auto()
    112    TINYTEXT = auto()
    113    BINARY = auto()
    114    VARBINARY = auto()
    115    JSON = auto()
    116    JSONB = auto()
    117    TIME = auto()
    118    TIMETZ = auto()
    119    TIMESTAMP = auto()
    120    TIMESTAMPTZ = auto()
    121    TIMESTAMPLTZ = auto()
    122    TIMESTAMP_S = auto()
    123    TIMESTAMP_MS = auto()
    124    TIMESTAMP_NS = auto()
    125    DATETIME = auto()
    126    DATETIME64 = auto()
    127    DATE = auto()
    128    INT4RANGE = auto()
    129    INT4MULTIRANGE = auto()
    130    INT8RANGE = auto()
    131    INT8MULTIRANGE = auto()
    132    NUMRANGE = auto()
    133    NUMMULTIRANGE = auto()
    134    TSRANGE = auto()
    135    TSMULTIRANGE = auto()
    136    TSTZRANGE = auto()
    137    TSTZMULTIRANGE = auto()
    138    DATERANGE = auto()
    139    DATEMULTIRANGE = auto()
    140    UUID = auto()
    141    GEOGRAPHY = auto()
    142    NULLABLE = auto()
    143    GEOMETRY = auto()
    144    HLLSKETCH = auto()
    145    HSTORE = auto()
    146    SUPER = auto()
    147    SERIAL = auto()
    148    SMALLSERIAL = auto()
    149    BIGSERIAL = auto()
    150    XML = auto()
    151    YEAR = auto()
    152    UNIQUEIDENTIFIER = auto()
    153    USERDEFINED = auto()
    154    MONEY = auto()
    155    SMALLMONEY = auto()
    156    ROWVERSION = auto()
    157    IMAGE = auto()
    158    VARIANT = auto()
    159    OBJECT = auto()
    160    INET = auto()
    161    IPADDRESS = auto()
    162    IPPREFIX = auto()
    163    ENUM = auto()
    164    ENUM8 = auto()
    165    ENUM16 = auto()
    166    FIXEDSTRING = auto()
    167    LOWCARDINALITY = auto()
    168    NESTED = auto()
    169    UNKNOWN = auto()
    170
    171    # keywords
    172    ALIAS = auto()
    173    ALTER = auto()
    174    ALWAYS = auto()
    175    ALL = auto()
    176    ANTI = auto()
    177    ANY = auto()
    178    APPLY = auto()
    179    ARRAY = auto()
    180    ASC = auto()
    181    ASOF = auto()
    182    AUTO_INCREMENT = auto()
    183    BEGIN = auto()
    184    BETWEEN = auto()
    185    CACHE = auto()
    186    CASE = auto()
    187    CHARACTER_SET = auto()
    188    CLUSTER_BY = auto()
    189    COLLATE = auto()
    190    COMMAND = auto()
    191    COMMENT = auto()
    192    COMMIT = auto()
    193    CONNECT_BY = auto()
    194    CONSTRAINT = auto()
    195    CREATE = auto()
    196    CROSS = auto()
    197    CUBE = auto()
    198    CURRENT_DATE = auto()
    199    CURRENT_DATETIME = auto()
    200    CURRENT_TIME = auto()
    201    CURRENT_TIMESTAMP = auto()
    202    CURRENT_USER = auto()
    203    DEFAULT = auto()
    204    DELETE = auto()
    205    DESC = auto()
    206    DESCRIBE = auto()
    207    DICTIONARY = auto()
    208    DISTINCT = auto()
    209    DISTRIBUTE_BY = auto()
    210    DIV = auto()
    211    DROP = auto()
    212    ELSE = auto()
    213    END = auto()
    214    ESCAPE = auto()
    215    EXCEPT = auto()
    216    EXECUTE = auto()
    217    EXISTS = auto()
    218    FALSE = auto()
    219    FETCH = auto()
    220    FILTER = auto()
    221    FINAL = auto()
    222    FIRST = auto()
    223    FOR = auto()
    224    FORCE = auto()
    225    FOREIGN_KEY = auto()
    226    FORMAT = auto()
    227    FROM = auto()
    228    FULL = auto()
    229    FUNCTION = auto()
    230    GLOB = auto()
    231    GLOBAL = auto()
    232    GROUP_BY = auto()
    233    GROUPING_SETS = auto()
    234    HAVING = auto()
    235    HINT = auto()
    236    IGNORE = auto()
    237    ILIKE = auto()
    238    ILIKE_ANY = auto()
    239    IN = auto()
    240    INDEX = auto()
    241    INNER = auto()
    242    INSERT = auto()
    243    INTERSECT = auto()
    244    INTERVAL = auto()
    245    INTO = auto()
    246    INTRODUCER = auto()
    247    IRLIKE = auto()
    248    IS = auto()
    249    ISNULL = auto()
    250    JOIN = auto()
    251    JOIN_MARKER = auto()
    252    KEEP = auto()
    253    KILL = auto()
    254    LANGUAGE = auto()
    255    LATERAL = auto()
    256    LEFT = auto()
    257    LIKE = auto()
    258    LIKE_ANY = auto()
    259    LIMIT = auto()
    260    LOAD = auto()
    261    LOCK = auto()
    262    MAP = auto()
    263    MATCH_RECOGNIZE = auto()
    264    MEMBER_OF = auto()
    265    MERGE = auto()
    266    MOD = auto()
    267    MODEL = auto()
    268    NATURAL = auto()
    269    NEXT = auto()
    270    NOTNULL = auto()
    271    NULL = auto()
    272    OBJECT_IDENTIFIER = auto()
    273    OFFSET = auto()
    274    ON = auto()
    275    OPERATOR = auto()
    276    ORDER_BY = auto()
    277    ORDERED = auto()
    278    ORDINALITY = auto()
    279    OUTER = auto()
    280    OVER = auto()
    281    OVERLAPS = auto()
    282    OVERWRITE = auto()
    283    PARTITION = auto()
    284    PARTITION_BY = auto()
    285    PERCENT = auto()
    286    PIVOT = auto()
    287    PLACEHOLDER = auto()
    288    PRAGMA = auto()
    289    PRIMARY_KEY = auto()
    290    PROCEDURE = auto()
    291    PROPERTIES = auto()
    292    PSEUDO_TYPE = auto()
    293    QUALIFY = auto()
    294    QUOTE = auto()
    295    RANGE = auto()
    296    RECURSIVE = auto()
    297    REFRESH = auto()
    298    REPLACE = auto()
    299    RETURNING = auto()
    300    REFERENCES = auto()
    301    RIGHT = auto()
    302    RLIKE = auto()
    303    ROLLBACK = auto()
    304    ROLLUP = auto()
    305    ROW = auto()
    306    ROWS = auto()
    307    SELECT = auto()
    308    SEMI = auto()
    309    SEPARATOR = auto()
    310    SERDE_PROPERTIES = auto()
    311    SET = auto()
    312    SETTINGS = auto()
    313    SHOW = auto()
    314    SIMILAR_TO = auto()
    315    SOME = auto()
    316    SORT_BY = auto()
    317    START_WITH = auto()
    318    STRUCT = auto()
    319    TABLE_SAMPLE = auto()
    320    TEMPORARY = auto()
    321    TOP = auto()
    322    THEN = auto()
    323    TRUE = auto()
    324    UNCACHE = auto()
    325    UNION = auto()
    326    UNNEST = auto()
    327    UNPIVOT = auto()
    328    UPDATE = auto()
    329    USE = auto()
    330    USING = auto()
    331    VALUES = auto()
    332    VIEW = auto()
    333    VOLATILE = auto()
    334    WHEN = auto()
    335    WHERE = auto()
    336    WINDOW = auto()
    337    WITH = auto()
    338    UNIQUE = auto()
    339    VERSION_SNAPSHOT = auto()
    340    TIMESTAMP_SNAPSHOT = auto()

An enumeration.

L_PAREN = <TokenType.L_PAREN: 'L_PAREN'>
R_PAREN = <TokenType.R_PAREN: 'R_PAREN'>
L_BRACKET = <TokenType.L_BRACKET: 'L_BRACKET'>
R_BRACKET = <TokenType.R_BRACKET: 'R_BRACKET'>
L_BRACE = <TokenType.L_BRACE: 'L_BRACE'>
R_BRACE = <TokenType.R_BRACE: 'R_BRACE'>
COMMA = <TokenType.COMMA: 'COMMA'>
DOT = <TokenType.DOT: 'DOT'>
DASH = <TokenType.DASH: 'DASH'>
PLUS = <TokenType.PLUS: 'PLUS'>
COLON = <TokenType.COLON: 'COLON'>
DCOLON = <TokenType.DCOLON: 'DCOLON'>
DQMARK = <TokenType.DQMARK: 'DQMARK'>
SEMICOLON = <TokenType.SEMICOLON: 'SEMICOLON'>
STAR = <TokenType.STAR: 'STAR'>
BACKSLASH = <TokenType.BACKSLASH: 'BACKSLASH'>
SLASH = <TokenType.SLASH: 'SLASH'>
LT = <TokenType.LT: 'LT'>
LTE = <TokenType.LTE: 'LTE'>
GT = <TokenType.GT: 'GT'>
GTE = <TokenType.GTE: 'GTE'>
NOT = <TokenType.NOT: 'NOT'>
EQ = <TokenType.EQ: 'EQ'>
NEQ = <TokenType.NEQ: 'NEQ'>
NULLSAFE_EQ = <TokenType.NULLSAFE_EQ: 'NULLSAFE_EQ'>
COLON_EQ = <TokenType.COLON_EQ: 'COLON_EQ'>
AND = <TokenType.AND: 'AND'>
OR = <TokenType.OR: 'OR'>
AMP = <TokenType.AMP: 'AMP'>
DPIPE = <TokenType.DPIPE: 'DPIPE'>
PIPE = <TokenType.PIPE: 'PIPE'>
CARET = <TokenType.CARET: 'CARET'>
TILDA = <TokenType.TILDA: 'TILDA'>
ARROW = <TokenType.ARROW: 'ARROW'>
DARROW = <TokenType.DARROW: 'DARROW'>
FARROW = <TokenType.FARROW: 'FARROW'>
HASH = <TokenType.HASH: 'HASH'>
HASH_ARROW = <TokenType.HASH_ARROW: 'HASH_ARROW'>
DHASH_ARROW = <TokenType.DHASH_ARROW: 'DHASH_ARROW'>
LR_ARROW = <TokenType.LR_ARROW: 'LR_ARROW'>
DAT = <TokenType.DAT: 'DAT'>
LT_AT = <TokenType.LT_AT: 'LT_AT'>
AT_GT = <TokenType.AT_GT: 'AT_GT'>
DOLLAR = <TokenType.DOLLAR: 'DOLLAR'>
PARAMETER = <TokenType.PARAMETER: 'PARAMETER'>
SESSION_PARAMETER = <TokenType.SESSION_PARAMETER: 'SESSION_PARAMETER'>
DAMP = <TokenType.DAMP: 'DAMP'>
XOR = <TokenType.XOR: 'XOR'>
DSTAR = <TokenType.DSTAR: 'DSTAR'>
BLOCK_START = <TokenType.BLOCK_START: 'BLOCK_START'>
BLOCK_END = <TokenType.BLOCK_END: 'BLOCK_END'>
SPACE = <TokenType.SPACE: 'SPACE'>
BREAK = <TokenType.BREAK: 'BREAK'>
STRING = <TokenType.STRING: 'STRING'>
NUMBER = <TokenType.NUMBER: 'NUMBER'>
IDENTIFIER = <TokenType.IDENTIFIER: 'IDENTIFIER'>
DATABASE = <TokenType.DATABASE: 'DATABASE'>
COLUMN = <TokenType.COLUMN: 'COLUMN'>
COLUMN_DEF = <TokenType.COLUMN_DEF: 'COLUMN_DEF'>
SCHEMA = <TokenType.SCHEMA: 'SCHEMA'>
TABLE = <TokenType.TABLE: 'TABLE'>
VAR = <TokenType.VAR: 'VAR'>
BIT_STRING = <TokenType.BIT_STRING: 'BIT_STRING'>
HEX_STRING = <TokenType.HEX_STRING: 'HEX_STRING'>
BYTE_STRING = <TokenType.BYTE_STRING: 'BYTE_STRING'>
NATIONAL_STRING = <TokenType.NATIONAL_STRING: 'NATIONAL_STRING'>
RAW_STRING = <TokenType.RAW_STRING: 'RAW_STRING'>
HEREDOC_STRING = <TokenType.HEREDOC_STRING: 'HEREDOC_STRING'>
BIT = <TokenType.BIT: 'BIT'>
BOOLEAN = <TokenType.BOOLEAN: 'BOOLEAN'>
TINYINT = <TokenType.TINYINT: 'TINYINT'>
UTINYINT = <TokenType.UTINYINT: 'UTINYINT'>
SMALLINT = <TokenType.SMALLINT: 'SMALLINT'>
USMALLINT = <TokenType.USMALLINT: 'USMALLINT'>
MEDIUMINT = <TokenType.MEDIUMINT: 'MEDIUMINT'>
UMEDIUMINT = <TokenType.UMEDIUMINT: 'UMEDIUMINT'>
INT = <TokenType.INT: 'INT'>
UINT = <TokenType.UINT: 'UINT'>
BIGINT = <TokenType.BIGINT: 'BIGINT'>
UBIGINT = <TokenType.UBIGINT: 'UBIGINT'>
INT128 = <TokenType.INT128: 'INT128'>
UINT128 = <TokenType.UINT128: 'UINT128'>
INT256 = <TokenType.INT256: 'INT256'>
UINT256 = <TokenType.UINT256: 'UINT256'>
FLOAT = <TokenType.FLOAT: 'FLOAT'>
DOUBLE = <TokenType.DOUBLE: 'DOUBLE'>
DECIMAL = <TokenType.DECIMAL: 'DECIMAL'>
UDECIMAL = <TokenType.UDECIMAL: 'UDECIMAL'>
BIGDECIMAL = <TokenType.BIGDECIMAL: 'BIGDECIMAL'>
CHAR = <TokenType.CHAR: 'CHAR'>
NCHAR = <TokenType.NCHAR: 'NCHAR'>
VARCHAR = <TokenType.VARCHAR: 'VARCHAR'>
NVARCHAR = <TokenType.NVARCHAR: 'NVARCHAR'>
TEXT = <TokenType.TEXT: 'TEXT'>
MEDIUMTEXT = <TokenType.MEDIUMTEXT: 'MEDIUMTEXT'>
LONGTEXT = <TokenType.LONGTEXT: 'LONGTEXT'>
MEDIUMBLOB = <TokenType.MEDIUMBLOB: 'MEDIUMBLOB'>
LONGBLOB = <TokenType.LONGBLOB: 'LONGBLOB'>
TINYBLOB = <TokenType.TINYBLOB: 'TINYBLOB'>
TINYTEXT = <TokenType.TINYTEXT: 'TINYTEXT'>
BINARY = <TokenType.BINARY: 'BINARY'>
VARBINARY = <TokenType.VARBINARY: 'VARBINARY'>
JSON = <TokenType.JSON: 'JSON'>
JSONB = <TokenType.JSONB: 'JSONB'>
TIME = <TokenType.TIME: 'TIME'>
TIMETZ = <TokenType.TIMETZ: 'TIMETZ'>
TIMESTAMP = <TokenType.TIMESTAMP: 'TIMESTAMP'>
TIMESTAMPTZ = <TokenType.TIMESTAMPTZ: 'TIMESTAMPTZ'>
TIMESTAMPLTZ = <TokenType.TIMESTAMPLTZ: 'TIMESTAMPLTZ'>
TIMESTAMP_S = <TokenType.TIMESTAMP_S: 'TIMESTAMP_S'>
TIMESTAMP_MS = <TokenType.TIMESTAMP_MS: 'TIMESTAMP_MS'>
TIMESTAMP_NS = <TokenType.TIMESTAMP_NS: 'TIMESTAMP_NS'>
DATETIME = <TokenType.DATETIME: 'DATETIME'>
DATETIME64 = <TokenType.DATETIME64: 'DATETIME64'>
DATE = <TokenType.DATE: 'DATE'>
INT4RANGE = <TokenType.INT4RANGE: 'INT4RANGE'>
INT4MULTIRANGE = <TokenType.INT4MULTIRANGE: 'INT4MULTIRANGE'>
INT8RANGE = <TokenType.INT8RANGE: 'INT8RANGE'>
INT8MULTIRANGE = <TokenType.INT8MULTIRANGE: 'INT8MULTIRANGE'>
NUMRANGE = <TokenType.NUMRANGE: 'NUMRANGE'>
NUMMULTIRANGE = <TokenType.NUMMULTIRANGE: 'NUMMULTIRANGE'>
TSRANGE = <TokenType.TSRANGE: 'TSRANGE'>
TSMULTIRANGE = <TokenType.TSMULTIRANGE: 'TSMULTIRANGE'>
TSTZRANGE = <TokenType.TSTZRANGE: 'TSTZRANGE'>
TSTZMULTIRANGE = <TokenType.TSTZMULTIRANGE: 'TSTZMULTIRANGE'>
DATERANGE = <TokenType.DATERANGE: 'DATERANGE'>
DATEMULTIRANGE = <TokenType.DATEMULTIRANGE: 'DATEMULTIRANGE'>
UUID = <TokenType.UUID: 'UUID'>
GEOGRAPHY = <TokenType.GEOGRAPHY: 'GEOGRAPHY'>
NULLABLE = <TokenType.NULLABLE: 'NULLABLE'>
GEOMETRY = <TokenType.GEOMETRY: 'GEOMETRY'>
HLLSKETCH = <TokenType.HLLSKETCH: 'HLLSKETCH'>
HSTORE = <TokenType.HSTORE: 'HSTORE'>
SUPER = <TokenType.SUPER: 'SUPER'>
SERIAL = <TokenType.SERIAL: 'SERIAL'>
SMALLSERIAL = <TokenType.SMALLSERIAL: 'SMALLSERIAL'>
BIGSERIAL = <TokenType.BIGSERIAL: 'BIGSERIAL'>
XML = <TokenType.XML: 'XML'>
YEAR = <TokenType.YEAR: 'YEAR'>
UNIQUEIDENTIFIER = <TokenType.UNIQUEIDENTIFIER: 'UNIQUEIDENTIFIER'>
USERDEFINED = <TokenType.USERDEFINED: 'USERDEFINED'>
MONEY = <TokenType.MONEY: 'MONEY'>
SMALLMONEY = <TokenType.SMALLMONEY: 'SMALLMONEY'>
ROWVERSION = <TokenType.ROWVERSION: 'ROWVERSION'>
IMAGE = <TokenType.IMAGE: 'IMAGE'>
VARIANT = <TokenType.VARIANT: 'VARIANT'>
OBJECT = <TokenType.OBJECT: 'OBJECT'>
INET = <TokenType.INET: 'INET'>
IPADDRESS = <TokenType.IPADDRESS: 'IPADDRESS'>
IPPREFIX = <TokenType.IPPREFIX: 'IPPREFIX'>
ENUM = <TokenType.ENUM: 'ENUM'>
ENUM8 = <TokenType.ENUM8: 'ENUM8'>
ENUM16 = <TokenType.ENUM16: 'ENUM16'>
FIXEDSTRING = <TokenType.FIXEDSTRING: 'FIXEDSTRING'>
LOWCARDINALITY = <TokenType.LOWCARDINALITY: 'LOWCARDINALITY'>
NESTED = <TokenType.NESTED: 'NESTED'>
UNKNOWN = <TokenType.UNKNOWN: 'UNKNOWN'>
ALIAS = <TokenType.ALIAS: 'ALIAS'>
ALTER = <TokenType.ALTER: 'ALTER'>
ALWAYS = <TokenType.ALWAYS: 'ALWAYS'>
ALL = <TokenType.ALL: 'ALL'>
ANTI = <TokenType.ANTI: 'ANTI'>
ANY = <TokenType.ANY: 'ANY'>
APPLY = <TokenType.APPLY: 'APPLY'>
ARRAY = <TokenType.ARRAY: 'ARRAY'>
ASC = <TokenType.ASC: 'ASC'>
ASOF = <TokenType.ASOF: 'ASOF'>
AUTO_INCREMENT = <TokenType.AUTO_INCREMENT: 'AUTO_INCREMENT'>
BEGIN = <TokenType.BEGIN: 'BEGIN'>
BETWEEN = <TokenType.BETWEEN: 'BETWEEN'>
CACHE = <TokenType.CACHE: 'CACHE'>
CASE = <TokenType.CASE: 'CASE'>
CHARACTER_SET = <TokenType.CHARACTER_SET: 'CHARACTER_SET'>
CLUSTER_BY = <TokenType.CLUSTER_BY: 'CLUSTER_BY'>
COLLATE = <TokenType.COLLATE: 'COLLATE'>
COMMAND = <TokenType.COMMAND: 'COMMAND'>
COMMENT = <TokenType.COMMENT: 'COMMENT'>
COMMIT = <TokenType.COMMIT: 'COMMIT'>
CONNECT_BY = <TokenType.CONNECT_BY: 'CONNECT_BY'>
CONSTRAINT = <TokenType.CONSTRAINT: 'CONSTRAINT'>
CREATE = <TokenType.CREATE: 'CREATE'>
CROSS = <TokenType.CROSS: 'CROSS'>
CUBE = <TokenType.CUBE: 'CUBE'>
CURRENT_DATE = <TokenType.CURRENT_DATE: 'CURRENT_DATE'>
CURRENT_DATETIME = <TokenType.CURRENT_DATETIME: 'CURRENT_DATETIME'>
CURRENT_TIME = <TokenType.CURRENT_TIME: 'CURRENT_TIME'>
CURRENT_TIMESTAMP = <TokenType.CURRENT_TIMESTAMP: 'CURRENT_TIMESTAMP'>
CURRENT_USER = <TokenType.CURRENT_USER: 'CURRENT_USER'>
DEFAULT = <TokenType.DEFAULT: 'DEFAULT'>
DELETE = <TokenType.DELETE: 'DELETE'>
DESC = <TokenType.DESC: 'DESC'>
DESCRIBE = <TokenType.DESCRIBE: 'DESCRIBE'>
DICTIONARY = <TokenType.DICTIONARY: 'DICTIONARY'>
DISTINCT = <TokenType.DISTINCT: 'DISTINCT'>
DISTRIBUTE_BY = <TokenType.DISTRIBUTE_BY: 'DISTRIBUTE_BY'>
DIV = <TokenType.DIV: 'DIV'>
DROP = <TokenType.DROP: 'DROP'>
ELSE = <TokenType.ELSE: 'ELSE'>
END = <TokenType.END: 'END'>
ESCAPE = <TokenType.ESCAPE: 'ESCAPE'>
EXCEPT = <TokenType.EXCEPT: 'EXCEPT'>
EXECUTE = <TokenType.EXECUTE: 'EXECUTE'>
EXISTS = <TokenType.EXISTS: 'EXISTS'>
FALSE = <TokenType.FALSE: 'FALSE'>
FETCH = <TokenType.FETCH: 'FETCH'>
FILTER = <TokenType.FILTER: 'FILTER'>
FINAL = <TokenType.FINAL: 'FINAL'>
FIRST = <TokenType.FIRST: 'FIRST'>
FOR = <TokenType.FOR: 'FOR'>
FORCE = <TokenType.FORCE: 'FORCE'>
FOREIGN_KEY = <TokenType.FOREIGN_KEY: 'FOREIGN_KEY'>
FORMAT = <TokenType.FORMAT: 'FORMAT'>
FROM = <TokenType.FROM: 'FROM'>
FULL = <TokenType.FULL: 'FULL'>
FUNCTION = <TokenType.FUNCTION: 'FUNCTION'>
GLOB = <TokenType.GLOB: 'GLOB'>
GLOBAL = <TokenType.GLOBAL: 'GLOBAL'>
GROUP_BY = <TokenType.GROUP_BY: 'GROUP_BY'>
GROUPING_SETS = <TokenType.GROUPING_SETS: 'GROUPING_SETS'>
HAVING = <TokenType.HAVING: 'HAVING'>
HINT = <TokenType.HINT: 'HINT'>
IGNORE = <TokenType.IGNORE: 'IGNORE'>
ILIKE = <TokenType.ILIKE: 'ILIKE'>
ILIKE_ANY = <TokenType.ILIKE_ANY: 'ILIKE_ANY'>
IN = <TokenType.IN: 'IN'>
INDEX = <TokenType.INDEX: 'INDEX'>
INNER = <TokenType.INNER: 'INNER'>
INSERT = <TokenType.INSERT: 'INSERT'>
INTERSECT = <TokenType.INTERSECT: 'INTERSECT'>
INTERVAL = <TokenType.INTERVAL: 'INTERVAL'>
INTO = <TokenType.INTO: 'INTO'>
INTRODUCER = <TokenType.INTRODUCER: 'INTRODUCER'>
IRLIKE = <TokenType.IRLIKE: 'IRLIKE'>
IS = <TokenType.IS: 'IS'>
ISNULL = <TokenType.ISNULL: 'ISNULL'>
JOIN = <TokenType.JOIN: 'JOIN'>
JOIN_MARKER = <TokenType.JOIN_MARKER: 'JOIN_MARKER'>
KEEP = <TokenType.KEEP: 'KEEP'>
KILL = <TokenType.KILL: 'KILL'>
LANGUAGE = <TokenType.LANGUAGE: 'LANGUAGE'>
LATERAL = <TokenType.LATERAL: 'LATERAL'>
LEFT = <TokenType.LEFT: 'LEFT'>
LIKE = <TokenType.LIKE: 'LIKE'>
LIKE_ANY = <TokenType.LIKE_ANY: 'LIKE_ANY'>
LIMIT = <TokenType.LIMIT: 'LIMIT'>
LOAD = <TokenType.LOAD: 'LOAD'>
LOCK = <TokenType.LOCK: 'LOCK'>
MAP = <TokenType.MAP: 'MAP'>
MATCH_RECOGNIZE = <TokenType.MATCH_RECOGNIZE: 'MATCH_RECOGNIZE'>
MEMBER_OF = <TokenType.MEMBER_OF: 'MEMBER_OF'>
MERGE = <TokenType.MERGE: 'MERGE'>
MOD = <TokenType.MOD: 'MOD'>
MODEL = <TokenType.MODEL: 'MODEL'>
NATURAL = <TokenType.NATURAL: 'NATURAL'>
NEXT = <TokenType.NEXT: 'NEXT'>
NOTNULL = <TokenType.NOTNULL: 'NOTNULL'>
NULL = <TokenType.NULL: 'NULL'>
OBJECT_IDENTIFIER = <TokenType.OBJECT_IDENTIFIER: 'OBJECT_IDENTIFIER'>
OFFSET = <TokenType.OFFSET: 'OFFSET'>
ON = <TokenType.ON: 'ON'>
OPERATOR = <TokenType.OPERATOR: 'OPERATOR'>
ORDER_BY = <TokenType.ORDER_BY: 'ORDER_BY'>
ORDERED = <TokenType.ORDERED: 'ORDERED'>
ORDINALITY = <TokenType.ORDINALITY: 'ORDINALITY'>
OUTER = <TokenType.OUTER: 'OUTER'>
OVER = <TokenType.OVER: 'OVER'>
OVERLAPS = <TokenType.OVERLAPS: 'OVERLAPS'>
OVERWRITE = <TokenType.OVERWRITE: 'OVERWRITE'>
PARTITION = <TokenType.PARTITION: 'PARTITION'>
PARTITION_BY = <TokenType.PARTITION_BY: 'PARTITION_BY'>
PERCENT = <TokenType.PERCENT: 'PERCENT'>
PIVOT = <TokenType.PIVOT: 'PIVOT'>
PLACEHOLDER = <TokenType.PLACEHOLDER: 'PLACEHOLDER'>
PRAGMA = <TokenType.PRAGMA: 'PRAGMA'>
PRIMARY_KEY = <TokenType.PRIMARY_KEY: 'PRIMARY_KEY'>
PROCEDURE = <TokenType.PROCEDURE: 'PROCEDURE'>
PROPERTIES = <TokenType.PROPERTIES: 'PROPERTIES'>
PSEUDO_TYPE = <TokenType.PSEUDO_TYPE: 'PSEUDO_TYPE'>
QUALIFY = <TokenType.QUALIFY: 'QUALIFY'>
QUOTE = <TokenType.QUOTE: 'QUOTE'>
RANGE = <TokenType.RANGE: 'RANGE'>
RECURSIVE = <TokenType.RECURSIVE: 'RECURSIVE'>
REFRESH = <TokenType.REFRESH: 'REFRESH'>
REPLACE = <TokenType.REPLACE: 'REPLACE'>
RETURNING = <TokenType.RETURNING: 'RETURNING'>
REFERENCES = <TokenType.REFERENCES: 'REFERENCES'>
RIGHT = <TokenType.RIGHT: 'RIGHT'>
RLIKE = <TokenType.RLIKE: 'RLIKE'>
ROLLBACK = <TokenType.ROLLBACK: 'ROLLBACK'>
ROLLUP = <TokenType.ROLLUP: 'ROLLUP'>
ROW = <TokenType.ROW: 'ROW'>
ROWS = <TokenType.ROWS: 'ROWS'>
SELECT = <TokenType.SELECT: 'SELECT'>
SEMI = <TokenType.SEMI: 'SEMI'>
SEPARATOR = <TokenType.SEPARATOR: 'SEPARATOR'>
SERDE_PROPERTIES = <TokenType.SERDE_PROPERTIES: 'SERDE_PROPERTIES'>
SET = <TokenType.SET: 'SET'>
SETTINGS = <TokenType.SETTINGS: 'SETTINGS'>
SHOW = <TokenType.SHOW: 'SHOW'>
SIMILAR_TO = <TokenType.SIMILAR_TO: 'SIMILAR_TO'>
SOME = <TokenType.SOME: 'SOME'>
SORT_BY = <TokenType.SORT_BY: 'SORT_BY'>
START_WITH = <TokenType.START_WITH: 'START_WITH'>
STRUCT = <TokenType.STRUCT: 'STRUCT'>
TABLE_SAMPLE = <TokenType.TABLE_SAMPLE: 'TABLE_SAMPLE'>
TEMPORARY = <TokenType.TEMPORARY: 'TEMPORARY'>
TOP = <TokenType.TOP: 'TOP'>
THEN = <TokenType.THEN: 'THEN'>
TRUE = <TokenType.TRUE: 'TRUE'>
UNCACHE = <TokenType.UNCACHE: 'UNCACHE'>
UNION = <TokenType.UNION: 'UNION'>
UNNEST = <TokenType.UNNEST: 'UNNEST'>
UNPIVOT = <TokenType.UNPIVOT: 'UNPIVOT'>
UPDATE = <TokenType.UPDATE: 'UPDATE'>
USE = <TokenType.USE: 'USE'>
USING = <TokenType.USING: 'USING'>
VALUES = <TokenType.VALUES: 'VALUES'>
VIEW = <TokenType.VIEW: 'VIEW'>
VOLATILE = <TokenType.VOLATILE: 'VOLATILE'>
WHEN = <TokenType.WHEN: 'WHEN'>
WHERE = <TokenType.WHERE: 'WHERE'>
WINDOW = <TokenType.WINDOW: 'WINDOW'>
WITH = <TokenType.WITH: 'WITH'>
UNIQUE = <TokenType.UNIQUE: 'UNIQUE'>
VERSION_SNAPSHOT = <TokenType.VERSION_SNAPSHOT: 'VERSION_SNAPSHOT'>
TIMESTAMP_SNAPSHOT = <TokenType.TIMESTAMP_SNAPSHOT: 'TIMESTAMP_SNAPSHOT'>

##### Inherited Members

enum.Enum
  name
  value